@@ -10,7 +10,7 @@ INSTALLED_APPS = (
     'django.contrib.sessions', 
     'flatblocks',
 )
-LANGUAGE_CODE="no"
+LANGUAGE_CODE="ru"
 TEMPLATE_DIRS = (
     os.path.join(os.path.dirname(__file__), 'templates'),
 )
